# birdgame

Utilities for the Bird Game at [crunchdao.com](https://crunchdao.com).

## Install

```bash
pip install birdgame
```

## Examples 


## General Bird Game Advice 

- [Literature](https://github.com/microprediction/birdgame/blob/main/LITERATURE.md) 
- Useful Python [packages](https://github.com/microprediction/birdgame/blob/main/PACKAGES.md)

